#!/usr/bin/env bash
#
# Bootstrap drubuntu.
#

CORE_VERSION='6.x'
DEFAULT_WORKSPACE=$HOME/workspace

echo
echo 'This script bootstraps Drubuntu, by ensuring PHP, Git, the latest Drush,'
echo 'and Drubuntu projects are installed and available.'
echo 'Once this is complete you will be able to install the drubuntu environment.'

echo
read -n1 -p "Would you like to bootstrap the Drubuntu environment now? (y/n)"
echo
if [ "$REPLY" != "y" ]; then
  exit
fi

PACKAGES="git-core php5-cli"
echo "Please enter your password to install $PACKAGES."
sudo apt-get -y install $PACKAGES

# Create default directory structure.
mkdir -p $DEFAULT_WORKSPACE
mkdir -p $HOME/.drubuntu/backups

# Download drush (we use Git to encourage contribution).
cd $DEFAULT_WORKSPACE
if [ -d "$HOME/workspace/drush" ] ; then
  echo 'Backing up existing drush directory'
  mv drush $HOME/.drubuntu/backups/`date +%Y%m%d%H%M%s`-drush.backup
fi

git clone --branch 7.x-4.x http://git.drupal.org/project/drush.git
cd drush
git checkout 7.x-4.5
cd -

# Setup .profile
if grep -q drush ~/.profile 
  then
    echo 'Drush appears to already be added to your ~/.profile.'
    echo 'Please check this file and ensure PATH includes $HOME/workspace/drush.'
  else
    echo '
# Set PATH so it includes drush if it exists.
if [ -d "$HOME/workspace/drush" ] ; then
  PATH="$HOME/workspace/drush:$PATH"
fi' >> ~/.profile
  UPDATE_PROFILE=1
fi
PATH="$HOME/workspace/drush:$PATH"
mkdir -p ~/.drush
if [ -d "$HOME/workspace/drubuntu" ] ; then
  echo 'Backing up existing drubuntu directory'
  mv drubuntu $HOME/.drubuntu/backups/`date +%Y%m%d%H%M%s`-drubuntu.backup
fi

if [ "$UPDATE_PROFILE" = 1 ] ; then
. ~/.profile
fi

drush dl --package-handler=git_drupalorg drubuntu --destination=.
ln -sfT $DEFAULT_WORKSPACE/drubuntu ~/.drush/drubuntu

echo
read -n1 -p "Would you like to install the full Drubuntu environment now? (y/n)"
echo
if [ "$REPLY" = "y" ]; then
  drush drubuntu-install
fi

echo 'Drubuntu bootstrap complete!'
